@@ -438,16 +438,18 @@ test_ui_file (GFile         *file,
   GtkStyleProvider *provider;
   GnomeWallClock *clock;
   GDateTime *datetime;
-  char *str, *set_locale;
+  char *str;
+  const char *previous_locale;
 
   ui_file = g_file_get_path (file);
 
   locale = get_locale_for_file (ui_file);
   g_assert (locale);
-  set_locale = setlocale (LC_ALL, locale);
-  g_assert_cmpstr (set_locale, ==, locale);
+  previous_locale = setlocale (LC_ALL, NULL);
+  setlocale (LC_ALL, locale);
+  g_assert_true (previous_locale != NULL);
 
-  clock = gnome_wall_clock_new();
+  clock = gnome_wall_clock_new ();
   datetime = g_date_time_new_local (2014, 5, 28, 23, 59, 59);
   str = gnome_wall_clock_string_for_datetime (clock,
 					      datetime,
@@ -457,6 +459,8 @@ test_ui_file (GFile         *file,
   g_date_time_unref (datetime);
   g_object_unref (clock);
 
+  setlocale (LC_ALL, previous_locale);
+
   provider = add_extra_css (ui_file, ".css");
 
   ui_image = snapshot_ui_file (ui_file, str);
@@ -570,13 +574,21 @@ main (int argc, char **argv)
   const char *basedir;
   GFile *file;
 
+  /* unset environment variables that can interfere with our tests */
+  unsetenv("LANG");
+  unsetenv("LANGUAGE");
+  unsetenv("LC_ALL");
+  unsetenv("LC_TIME");
+
+  /* gdk_cairo_set_source_window() doesn't work with anything but X11 */
+  gdk_set_allowed_backends ("x11");
+
   /* I don't want to fight fuzzy scaling algorithms in GPUs,
    * so unless you explicitly set it to something else, we
    * will use Cairo's image surface.
    */
   g_setenv ("GDK_RENDERING", "image", FALSE);
 
-  setlocale (LC_ALL, "");
   g_test_init (&argc, &argv, NULL);
   gtk_init (&argc, &argv);
 
